@@ -10,6 +10,7 @@ import time
 import traceback
 from concurrent.futures import ThreadPoolExecutor
 from typing import Any, Dict, List, Optional, Union
+from qcelemental.models import ComputeError
 
 import tornado.ioloop
 import tornado.log
@@ -274,7 +275,7 @@ class FractalServer:
             "version": get_information("version"),
             "query_limit": self.storage.get_limit(1.0e9),
             "client_lower_version_limit": "0.14.0",  # Must be XX.YY.ZZ
-            "client_upper_version_limit": "0.14.99",  # Must be XX.YY.ZZ
+            "client_upper_version_limit": "0.15.99",  # Must be XX.YY.ZZ
         }
         self.update_public_information()
 
@@ -517,6 +518,12 @@ class FractalServer:
         completed_services = []
         for data in current_services:
 
+            # TODO HACK: remove task_id from 'output'. This is contained in services
+            # created in previous versions. Doing this now, but should do a db migration
+            # at some point
+            if "output" in data:
+                data["output"].pop("task_id", None)
+
             # Attempt to iteration and get message
             try:
                 service = construct_service(self.storage, self.logger, data)
@@ -525,7 +532,7 @@ class FractalServer:
                 error_message = "FractalServer Service Build and Iterate Error:\n{}".format(traceback.format_exc())
                 self.logger.error(error_message)
                 service.status = "ERROR"
-                service.error = {"error_type": "iteration_error", "error_message": error_message}
+                service.error = ComputeError(error_type="iteration_error", error_message=error_message)
                 finished = False
 
             self.storage.update_services([service])
@@ -543,6 +550,8 @@ class FractalServer:
         if len(completed_services):
             self.logger.info(f"Completed {len(completed_services)} services.")
 
+        self.logger.debug(f"Done updating services.")
+
         # Add new procedures and services
         self.storage.services_completed(completed_services)
 
